MethodChannelFlutterLocalAuthentication class

An implementation of FlutterLocalAuthenticationPlatform that uses method channels.

Author: Ezequiel (Kimi) Aceto Email: ezequiel.aceto@gmail.com Website: https://kimi.blog

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<bool>
Requests biometric authentication using the Flutter Local Authentication plugin.
override
canAuthenticate({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<bool>
Checks whether biometric authentication is available on the device.
override
cancelAuthentication() → Future<bool>
Dismisses the authentication prompt that is being shown, if any.
override
getAvailability({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<AuthenticationAvailability>
Tells whether the user can authenticate with the given method, and the reason why when they can not.
override
getBiometryType() → Future<BiometryType>
Returns the kind of biometrics of the device.
override
getTouchIDAuthenticationAllowableReuseDuration() → Future<double>
Retrieves the allowable reuse duration for Touch ID authentication (iOS only).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLocalizationModel(Map<String, dynamic> localizationModel) → Future<void>
override
setTouchIDAuthenticationAllowableReuseDuration(double duration) → Future<double>
Sets the allowable reuse duration for Touch ID authentication (iOS only).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited