FlutterLocalAuthenticationPlatform class abstract

An abstract platform interface for the Flutter Local Authentication plugin.

This platform interface defines the methods that must be implemented by platform-specific classes to provide biometric authentication functionality.

Author: Ezequiel (Kimi) Aceto Email: ezequiel.aceto@gmail.com Website: https://kimi.blog

Inheritance
  • Object
  • PlatformInterface
  • FlutterLocalAuthenticationPlatform
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<bool>
Requests biometric authentication using the Flutter Local Authentication plugin.
canAuthenticate({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<bool>
Checks whether biometric authentication is available on the device.
cancelAuthentication() → Future<bool>
Dismisses the authentication prompt that is being shown, if any.
getAvailability({AuthenticationMethod method = AuthenticationMethod.biometricsOnly}) → Future<AuthenticationAvailability>
Tells whether the user can authenticate with the given method, and the reason why when they can not.
getBiometryType() → Future<BiometryType>
Returns the kind of biometrics of the device.
getTouchIDAuthenticationAllowableReuseDuration() → Future<double>
Retrieves the allowable reuse duration for Touch ID authentication (iOS only).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLocalizationModel(Map<String, dynamic> localizationModel) → Future<void>
setTouchIDAuthenticationAllowableReuseDuration(double duration) → Future<double>
Sets the allowable reuse duration for Touch ID authentication (iOS only).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterLocalAuthenticationPlatform
The default instance of FlutterLocalAuthenticationPlatform to use.
getter/setter pair