LocalizationModel class

A model class to store localization strings for prompts and buttons.

Author: Ezequiel (Kimi) Aceto Email: ezequiel.aceto@gmail.com Website: https://kimi.blog

Constructors

LocalizationModel({required String promptDialogTitle, required String promptDialogReason, required String cancelButtonTitle})
Creates a new instance of LocalizationModel with the provided strings.
LocalizationModel.fromJson(Map<String, dynamic> json)
Creates a LocalizationModel instance from a JSON map.
factory

Properties

cancelButtonTitle → String
The title for the cancel button in the authentication prompt dialog.
final
hashCode → int
The hash code for this object.
no setterinherited
promptDialogReason → String
The reason displayed in the authentication prompt dialog.
final
promptDialogTitle → String
The title for the authentication prompt dialog.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the LocalizationModel instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited